
# Slot: is sequence variant of


holds between a sequence variant and a genomic entity

URI: [biolink:is_sequence_variant_of](https://w3id.org/biolink/vocab/is_sequence_variant_of)


## Domain and Range

[SequenceVariant](SequenceVariant.md) &#8594;  <sub>0..\*</sub> [GenomicEntity](GenomicEntity.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [is frameshift variant of](is_frameshift_variant_of.md)
 *  [is missense variant of](is_missense_variant_of.md)
 *  [is nearby variant of](is_nearby_variant_of.md)
 *  [is non coding variant of](is_non_coding_variant_of.md)
 *  [is nonsense variant of](is_nonsense_variant_of.md)
 *  [is splice site variant of](is_splice_site_variant_of.md)
 *  [is synonymous variant of](is_synonymous_variant_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Narrow Mappings:** | | NCIT:gene_product_sequence_variation_encoded_by_gene_mutant |
|  | | NCIT:gene_product_variant_of_gene_product |
|  | | OMIM:allelic_variant_of |
|  | | WIKIDATA:P3433 |

